Adjust clang format to the new versions, revert broken macro layout (#714)

This commit is contained in:
Danylo Lytovchenko
2025-08-22 17:23:22 +02:00
committed by GitHub
parent ed877433f3
commit 2ff2316227
189 changed files with 1906 additions and 2418 deletions
@@ -60,7 +60,7 @@ TEMPLATE_TEST_CASE("Unit_hipTexObjPitch_texture2D", "", char, unsigned char, sho
CHECK_IMAGE_SUPPORT
#if HT_NVIDIA
(void)
hipGetLastError(); // Prevent negative tests affecting this
hipGetLastError(); // Prevent negative tests affecting this
#endif
#if __HIP_NO_IMAGE_SUPPORT
HipTest::HIP_SKIP_TEST("__HIP_NO_IMAGE_SUPPORT is set");
@@ -59,9 +59,8 @@ static __global__ void populateMipmapNextLevelArray(hipSurfaceObject_t surfOut,
#endif
}
template <typename T>
__global__ void getMipmap(hipTextureObject_t texMipmap, unsigned int width, float offsetX,
float lod, T* data = nullptr) {
template <typename T> __global__ void getMipmap(hipTextureObject_t texMipmap, unsigned int width,
float offsetX, float lod, T* data = nullptr) {
#if !__HIP_NO_IMAGE_SUPPORT
int x = blockIdx.x * blockDim.x + threadIdx.x;
float px = 1.0 / float(width);
@@ -69,10 +69,10 @@ static __global__ void populateMipmapNextLevelArray(hipSurfaceObject_t surfOut,
#endif
}
template <typename T>
static __global__ void getMipmap(hipTextureObject_t texMipmap, unsigned int width,
unsigned int height, float offsetX, float offsetY, float lod,
T* data = nullptr) {
template <typename T> static __global__ void getMipmap(hipTextureObject_t texMipmap,
unsigned int width, unsigned int height,
float offsetX, float offsetY, float lod,
T* data = nullptr) {
#if !__HIP_NO_IMAGE_SUPPORT
int x = blockIdx.x * blockDim.x + threadIdx.x;
int y = blockIdx.y * blockDim.y + threadIdx.y;
@@ -28,9 +28,9 @@ THE SOFTWARE.
* @ingroup TextureTest
*/
template <bool normalizedCoords>
__global__ void tex1DKernel(float* outputData, hipTextureObject_t textureObject, int width,
float offsetX) {
template <bool normalizedCoords> __global__ void tex1DKernel(float* outputData,
hipTextureObject_t textureObject,
int width, float offsetX) {
#if !__HIP_NO_IMAGE_SUPPORT
int x = blockIdx.x * blockDim.x + threadIdx.x;
outputData[x] =
@@ -22,9 +22,9 @@ THE SOFTWARE.
#include <hip_test_checkers.hh>
#include <hip_texture_helper.hh>
template <bool normalizedCoords>
__global__ void tex1DRGBAKernel(float4* outputData, hipTextureObject_t textureObject, int width,
float offsetX) {
template <bool normalizedCoords> __global__ void tex1DRGBAKernel(float4* outputData,
hipTextureObject_t textureObject,
int width, float offsetX) {
#if !__HIP_NO_IMAGE_SUPPORT
int x = blockIdx.x * blockDim.x + threadIdx.x;
outputData[x] =